@@ -23,7 +23,7 @@ from django.core.mail import EmailMultiAlternatives
 def build_redirect_url(request, default_url):
     """
     Retrieve redirect url from session.
-    
+
     Use default if retrieved one is broken or not safe.
     """
 
@@ -88,10 +88,6 @@ def render_to(template_path):
 
     Wrap view that return dict of variables, that should be used for
     rendering the template.
-    Dict returned from view could contain special keys:
-     * MIME_TYPE: mimetype of response
-     * TEMPLATE: template that should be used insted one that was
-                 specified in decorator argument
     """
 
     def decorator(func):
@@ -99,14 +95,9 @@ def render_to(template_path):
             output = func(request, *args, **kwargs)
             if not isinstance(output, dict):
                 return output
-            kwargs = {'context_instance': RequestContext(request)}
-            if 'MIME_TYPE' in output:
-                kwargs['mimetype'] = output.pop('MIME_TYPE')
-
-            template = template_path
-            if 'TEMPLATE' in output:
-                template = output.pop('TEMPLATE')
-            return render_to_response(template, output, **kwargs)
+            ctx = RequestContext(request)
+            return render_to_response(template_path, output,
+                                      context_instance=ctx)
         return wrapper
     return decorator
 
